@@ -34,10 +34,9 @@ class Pipeline:
 
         self.config: PipelineConfig = get_not_none(config, PipelineConfig())
 
-        # noinspection PyTypeChecker
-        all_pipeline_elements: Set[InternalPipelineElement] = set(self.event_generators + self.event_listeners.keys())
+        all_pipeline_elements: Set[InternalPipelineElement] = set(self.event_generators).union(self.event_listeners.keys())
         for element in all_pipeline_elements:
-            element.set_data_store(config.data_store)
+            element.set_data_store(self.config.data_store)
 
         # self.use_ray = (ray_config is not None)
         # self.ray_config = ray_config
