@@ -51,10 +51,12 @@ class DataStoreBranch(DataStore):
         result = self._parent_data_store.get_value(self._prefix + key)
         if result is None and self._value_generator is not None:
             result = self._value_generator(key)
-            self.set_value(key, result)
-            if self._change_event_handlers is not None and len(self._change_event_handlers) > 0 and self._change_indicator(None, result):
+            self._parent_data_store.set_value(self._prefix + key, result, None)
+            if (self._change_event_handlers is not None
+                    and len(self._change_event_handlers) > 0
+                    and self._change_indicator(None, result)):
                 for handler in self._change_event_handlers:
-                    handler(key, None, result)
+                    handler(key, None, result, None)
         return result
 
     def set_value(self, key: str, value: Any, cause: Event = None) -> None:
